window.Gleam.initSearch([{"doc":"deriv","title":"deriv","content":"# `deriv`\n\n[![Package Version](https://img.shields.io/hexpm/v/deriv)](https://hex.pm/packages/deriv)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/deriv/)\n\n```sh\ngleam add deriv@1\n```\n\n## Usage\n\n### `derive json`\n\n```gleam\nimport youid/uuid.{type Uuid}\n\npub type User {\n  //$ derive json decode encode\n  User(id: Uuid, name: String)\n}\n\npub type Post {\n  //$ derive json decode encode\n  Post(\n    id: Uuid,\n    title: String,\n    body: String,\n    //$ json named content\n    draft: Bool,\n    tags: List(String),\n    created_by: User,\n    meta_nested_key: String,\n    //$ json named meta.nested.key\n  )\n}\n```\n\n```\n$ gleam run -m deriv\n```\n\n```gleam\nimport decode.{type Decoder}\nimport deriv/util\nimport gleam/json.{type Json}\nimport gleam/list\nimport youid/uuid.{type Uuid}\n\npub type User {\n  //$ derive json decode encode\n  User(id: Uuid, name: String)\n}\n\npub type Post {\n  //$ derive json decode encode\n  Post(\n    id: Uuid,\n    title: String,\n    body: String,\n    //$ json named content\n    draft: Bool,\n    tags: List(String),\n    created_by: User,\n    meta_nested_key: String,\n    //$ json named meta.nested.key\n  )\n}\n\npub fn decoder_user() -&gt; Decoder(User) {\n  decode.one_of([decoder_user_user()])\n}\n\npub fn decoder_user_user() -&gt; Decoder(User) {\n  decode.into({\n    use id &lt;- decode.parameter\n    use name &lt;- decode.parameter\n    User(id:, name:)\n  })\n  |&gt; decode.field(&quot;id&quot;, util.decoder_uuid())\n  |&gt; decode.field(&quot;name&quot;, decode.string)\n}\n\npub fn encode_user(value: User) -&gt; Json {\n  case value {\n    User(..) as value -&gt;\n      json.object([\n        #(&quot;id&quot;, util.encode_uuid(value.id)),\n        #(&quot;name&quot;, json.string(value.name)),\n      ])\n  }\n}\n\npub fn decoder_post() -&gt; Decoder(Post) {\n  decode.one_of([decoder_post_post()])\n}\n\npub fn decoder_post_post() -&gt; Decoder(Post) {\n  decode.into({\n    use id &lt;- decode.parameter\n    use title &lt;- decode.parameter\n    use body &lt;- decode.parameter\n    use draft &lt;- decode.parameter\n    use tags &lt;- decode.parameter\n    use created_by &lt;- decode.parameter\n    use meta_nested_key &lt;- decode.parameter\n    Post(id:, title:, body:, draft:, tags:, created_by:, meta_nested_key:)\n  })\n  |&gt; decode.field(&quot;id&quot;, util.decoder_uuid())\n  |&gt; decode.field(&quot;title&quot;, decode.string)\n  |&gt; decode.field(&quot;content&quot;, decode.string)\n  |&gt; decode.field(&quot;draft&quot;, decode.bool)\n  |&gt; decode.field(&quot;tags&quot;, decode.list(decode.string))\n  |&gt; decode.field(&quot;created_by&quot;, decoder_user())\n  |&gt; decode.subfield([&quot;meta&quot;, &quot;nested&quot;, &quot;key&quot;], decode.string)\n}\n\npub fn encode_post(value: Post) -&gt; Json {\n  case value {\n    Post(..) as value -&gt;\n      json.object([\n        #(&quot;id&quot;, util.encode_uuid(value.id)),\n        #(&quot;title&quot;, json.string(value.title)),\n        #(&quot;content&quot;, json.string(value.body)),\n        #(&quot;draft&quot;, json.bool(value.draft)),\n        #(&quot;tags&quot;, json.preprocessed_array(list.map(value.tags, json.string))),\n        #(&quot;created_by&quot;, encode_user(value.created_by)),\n        #(\n          &quot;meta&quot;,\n          json.object([\n            #(\n              &quot;nested&quot;,\n              json.object([#(&quot;key&quot;, json.string(value.meta_nested_key))]),\n            ),\n          ]),\n        ),\n      ])\n  }\n}\n```\n\n### `derive unify`\n\n```gleam\n// src/project/types/person.gleam\npub type Person {\n  Person(\n    id: Int,\n    first_name: String,\n    last_name: String,\n    age: Int\n  )\n}\n```\n```gleam\n// src/project/types/pet.gleam\npub type Pet {\n  Pet(\n    id: Int,\n    name: String,\n  )\n}\n```\n```gleam\n// src/project/types/friend.gleam\nimport project/types/person.{type Person}\nimport project/types/pet.{type Pet}\n\npub type Friend {\n  //$ derive unify project/types/person.Person\n  //$ derive unify project/types/pet.Pet\n  Friend(\n    id: Int,\n    name: String,\n  )\n}\n```\n```\n$ gleam run -m deriv\n```\n```gleam\nimport project/types/person.{type Person}\nimport project/types/pet.{type Pet}\n\npub type Friend {\n  //$ derive unify project/types/person.Person\n  //$ derive unify project/types/pet.Pet\n  Friend(\n    name: String,\n    //$ unify field project/types/person.Person first_name\n  )\n}\n\npub fn person(value: Person) -&gt; Friend {\n  Friend(name: value.first_name)\n}\n\npub fn pet(value: Pet) -&gt; Friend {\n  Friend(name: value.name)\n}\n```\n## Development\n\n```sh\nmake watch-tests # NOTE: requires `entr`\n```\n","url":"index.html"},{"doc":"deriv/types","title":"DerivField","content":"pub type DerivField {\n  DerivField(type_: String, variant: String, field: String)\n}\n\nDerivField(type_: String, variant: String, field: String)\n\n\nSynonyms:\nderiv/types.DerivField\nderiv/types DerivField","url":"deriv/types.html#DerivField"},{"doc":"deriv/types","title":"DerivFieldOpt","content":"pub type DerivFieldOpt {\n  DerivFieldOpt(strs: List(String))\n}\n\nDerivFieldOpt(strs: List(String))\n\n\nSynonyms:\nderiv/types.DerivFieldOpt\nderiv/types DerivFieldOpt","url":"deriv/types.html#DerivFieldOpt"},{"doc":"deriv/types","title":"DerivFieldOpts","content":"pub type DerivFieldOpts =\n  Dict(DerivField, List(DerivFieldOpt))\n\n\nSynonyms:\nderiv/types.DerivFieldOpts\nderiv/types DerivFieldOpts","url":"deriv/types.html#DerivFieldOpts"},{"doc":"deriv/types","title":"Derivation","content":"pub type Derivation {\n  Derivation(name: String, opts: List(String))\n}\n\nDerivation(name: String, opts: List(String))\n\n\nSynonyms:\nderiv/types.Derivation\nderiv/types Derivation","url":"deriv/types.html#Derivation"},{"doc":"deriv/types","title":"File","content":"pub type File {\n  File(module: String, src: String, idx: Option(Int))\n}\n\nFile(module: String, src: String, idx: Option(Int))\n\n\nSynonyms:\nderiv/types.File\nderiv/types File","url":"deriv/types.html#File"},{"doc":"deriv/types","title":"Function","content":"pub type Function {\n  Function(\n    name: String,\n    src: String,\n    ast: glance.Definition(glance.Function),\n  )\n}\n\nFunction(\n  name: String,\n  src: String,\n  ast: glance.Definition(glance.Function),\n)\n\n\nSynonyms:\nderiv/types.Function\nderiv/types Function","url":"deriv/types.html#Function"},{"doc":"deriv/types","title":"Gen","content":"pub type Gen {\n  Gen(\n    file: File,\n    deriv: Derivation,\n    imports: List(Import),\n    funcs: List(Definition(glance.Function)),\n    src: String,\n    meta: Dict(String, String),\n  )\n}\n\nGen(\n  file: File,\n  deriv: Derivation,\n  imports: List(Import),\n  funcs: List(Definition(glance.Function)),\n  src: String,\n  meta: Dict(String, String),\n)\n\n\nSynonyms:\nderiv/types.Gen\nderiv/types Gen","url":"deriv/types.html#Gen"},{"doc":"deriv/types","title":"GenFunc","content":"pub type GenFunc =\n  fn(CustomType, Derivation, DerivFieldOpts, File, ModuleReader) -&gt;\n    Gen\n\n\nSynonyms:\nderiv/types.GenFunc\nderiv/types GenFunc","url":"deriv/types.html#GenFunc"},{"doc":"deriv/types","title":"ModuleReader","content":"pub type ModuleReader =\n  fn(String) -&gt; Result(Module, ModuleReaderErr)\n\n\nSynonyms:\nderiv/types.ModuleReader\nderiv/types ModuleReader","url":"deriv/types.html#ModuleReader"},{"doc":"deriv/types","title":"ModuleReaderErr","content":"pub type ModuleReaderErr {\n  FileErr(simplifile.FileError)\n  GlanceErr(glance.Error)\n  BadIdent(ident: String)\n  CustomTypeMissingErr(ident: String)\n}\n\nFileErr(simplifile.FileError)\n\n\nGlanceErr(glance.Error)\n\n\nBadIdent(ident: String)\n\n\nCustomTypeMissingErr(ident: String)\n\n\nSynonyms:\nderiv/types.ModuleReaderErr\nderiv/types ModuleReaderErr","url":"deriv/types.html#ModuleReaderErr"},{"doc":"deriv/types","title":"Output","content":"pub type Output {\n  Output(module: String, deriv: String)\n  OutputInline(module: String, filepath: String)\n}\n\nOutput(module: String, deriv: String)\n\n\nOutputInline(module: String, filepath: String)\n\n\nSynonyms:\nderiv/types.Output\nderiv/types Output","url":"deriv/types.html#Output"},{"doc":"deriv/types","title":"Write","content":"pub type Write {\n  Write(filepath: String, src: String, output: Output)\n}\n\nWrite(filepath: String, src: String, output: Output)\n\n\nSynonyms:\nderiv/types.Write\nderiv/types Write","url":"deriv/types.html#Write"},{"doc":"deriv/types","title":"deriv/types","content":"","url":"deriv/types.html"},{"doc":"deriv/parser","title":"parse_import_with_derivations","content":"pub fn parse_import_with_derivations(\n  import_: Import,\n  src: String,\n) -&gt; Result(#(Import, List(Derivation)), Nil)\n\nSynonyms:\nderiv/parser.parse_import_with_derivations\nderiv/parser parse_import_with_derivations","url":"deriv/parser.html#parse_import_with_derivations"},{"doc":"deriv/parser","title":"parse_type_with_derivations","content":"pub fn parse_type_with_derivations(\n  type_: CustomType,\n  src: String,\n) -&gt; Result(\n  #(\n    CustomType,\n    List(Derivation),\n    Dict(DerivField, List(DerivFieldOpt)),\n  ),\n  Nil,\n)\n\nSynonyms:\nderiv/parser.parse_type_with_derivations\nderiv/parser parse_type_with_derivations","url":"deriv/parser.html#parse_type_with_derivations"},{"doc":"deriv/parser","title":"suppress_option_warnings","content":"pub fn suppress_option_warnings() -&gt; List(Option(Nil))\n\nSynonyms:\nderiv/parser.suppress_option_warnings\nderiv/parser suppress_option_warnings","url":"deriv/parser.html#suppress_option_warnings"},{"doc":"deriv/parser","title":"deriv/parser","content":"","url":"deriv/parser.html"},{"doc":"deriv/util","title":"BirlTimeKind","content":"pub type BirlTimeKind {\n  BirlTimeISO8601\n  BirlTimeNaive\n  BirlTimeHTTP\n  BirlTimeUnix\n  BirlTimeUnixMilli\n  BirlTimeUnixMicro\n}\n\nBirlTimeISO8601\n\n\nBirlTimeNaive\n\n\nBirlTimeHTTP\n\n\nBirlTimeUnix\n\n\nBirlTimeUnixMilli\n\n\nBirlTimeUnixMicro\n\n\nSynonyms:\nderiv/util.BirlTimeKind\nderiv/util BirlTimeKind","url":"deriv/util.html#BirlTimeKind"},{"doc":"deriv/util","title":"birl_time_kind","content":"pub fn birl_time_kind(\n  type_: CustomType,\n  variant: Variant,\n  field: String,\n  all_field_opts: Dict(DerivField, List(DerivFieldOpt)),\n) -&gt; BirlTimeKind\n\nSynonyms:\nderiv/util.birl_time_kind\nderiv/util birl_time_kind","url":"deriv/util.html#birl_time_kind"},{"doc":"deriv/util","title":"decode_type_field","content":"pub fn decode_type_field(\n  variant variant: String,\n  json_field json_field: String,\n  pass decoder: Decoder(a),\n) -&gt; Decoder(a)\n\nSynonyms:\nderiv/util.decode_type_field\nderiv/util decode_type_field","url":"deriv/util.html#decode_type_field"},{"doc":"deriv/util","title":"decoder_birl_from_http","content":"pub fn decoder_birl_from_http() -&gt; Decoder(Time)\n\nSynonyms:\nderiv/util.decoder_birl_from_http\nderiv/util decoder_birl_from_http","url":"deriv/util.html#decoder_birl_from_http"},{"doc":"deriv/util","title":"decoder_birl_from_naive","content":"pub fn decoder_birl_from_naive() -&gt; Decoder(Time)\n\nSynonyms:\nderiv/util.decoder_birl_from_naive\nderiv/util decoder_birl_from_naive","url":"deriv/util.html#decoder_birl_from_naive"},{"doc":"deriv/util","title":"decoder_birl_from_unix","content":"pub fn decoder_birl_from_unix() -&gt; Decoder(Time)\n\nSynonyms:\nderiv/util.decoder_birl_from_unix\nderiv/util decoder_birl_from_unix","url":"deriv/util.html#decoder_birl_from_unix"},{"doc":"deriv/util","title":"decoder_birl_from_unix_micro","content":"pub fn decoder_birl_from_unix_micro() -&gt; Decoder(Time)\n\nSynonyms:\nderiv/util.decoder_birl_from_unix_micro\nderiv/util decoder_birl_from_unix_micro","url":"deriv/util.html#decoder_birl_from_unix_micro"},{"doc":"deriv/util","title":"decoder_birl_from_unix_milli","content":"pub fn decoder_birl_from_unix_milli() -&gt; Decoder(Time)\n\nSynonyms:\nderiv/util.decoder_birl_from_unix_milli\nderiv/util decoder_birl_from_unix_milli","url":"deriv/util.html#decoder_birl_from_unix_milli"},{"doc":"deriv/util","title":"decoder_birl_parse","content":"pub fn decoder_birl_parse() -&gt; Decoder(Time)\n\nSynonyms:\nderiv/util.decoder_birl_parse\nderiv/util decoder_birl_parse","url":"deriv/util.html#decoder_birl_parse"},{"doc":"deriv/util","title":"decoder_uuid","content":"pub fn decoder_uuid() -&gt; Decoder(Uuid)\n\nSynonyms:\nderiv/util.decoder_uuid\nderiv/util decoder_uuid","url":"deriv/util.html#decoder_uuid"},{"doc":"deriv/util","title":"encode_birl_to_http","content":"pub fn encode_birl_to_http(time: Time) -&gt; Json\n\nSynonyms:\nderiv/util.encode_birl_to_http\nderiv/util encode_birl_to_http","url":"deriv/util.html#encode_birl_to_http"},{"doc":"deriv/util","title":"encode_birl_to_iso8601","content":"pub fn encode_birl_to_iso8601(time: Time) -&gt; Json\n\nSynonyms:\nderiv/util.encode_birl_to_iso8601\nderiv/util encode_birl_to_iso8601","url":"deriv/util.html#encode_birl_to_iso8601"},{"doc":"deriv/util","title":"encode_birl_to_naive","content":"pub fn encode_birl_to_naive(time: Time) -&gt; Json\n\nSynonyms:\nderiv/util.encode_birl_to_naive\nderiv/util encode_birl_to_naive","url":"deriv/util.html#encode_birl_to_naive"},{"doc":"deriv/util","title":"encode_birl_to_unix","content":"pub fn encode_birl_to_unix(time: Time) -&gt; Json\n\nSynonyms:\nderiv/util.encode_birl_to_unix\nderiv/util encode_birl_to_unix","url":"deriv/util.html#encode_birl_to_unix"},{"doc":"deriv/util","title":"encode_birl_to_unix_micro","content":"pub fn encode_birl_to_unix_micro(time: Time) -&gt; Json\n\nSynonyms:\nderiv/util.encode_birl_to_unix_micro\nderiv/util encode_birl_to_unix_micro","url":"deriv/util.html#encode_birl_to_unix_micro"},{"doc":"deriv/util","title":"encode_birl_to_unix_milli","content":"pub fn encode_birl_to_unix_milli(time: Time) -&gt; Json\n\nSynonyms:\nderiv/util.encode_birl_to_unix_milli\nderiv/util encode_birl_to_unix_milli","url":"deriv/util.html#encode_birl_to_unix_milli"},{"doc":"deriv/util","title":"encode_uuid","content":"pub fn encode_uuid(uuid: Uuid) -&gt; Json\n\nSynonyms:\nderiv/util.encode_uuid\nderiv/util encode_uuid","url":"deriv/util.html#encode_uuid"},{"doc":"deriv/util","title":"fetch_custom_type","content":"pub fn fetch_custom_type(\n  ident: String,\n  read_module: fn(String) -&gt; Result(Module, ModuleReaderErr),\n) -&gt; Result(#(String, Definition(CustomType)), ModuleReaderErr)\n\nSynonyms:\nderiv/util.fetch_custom_type\nderiv/util fetch_custom_type","url":"deriv/util.html#fetch_custom_type"},{"doc":"deriv/util","title":"fetch_module","content":"pub fn fetch_module(\n  path: String,\n) -&gt; Result(Module, ModuleReaderErr)\n\nSynonyms:\nderiv/util.fetch_module\nderiv/util fetch_module","url":"deriv/util.html#fetch_module"},{"doc":"deriv/util","title":"func_name","content":"pub fn func_name(func: Definition(Function)) -&gt; String\n\nSynonyms:\nderiv/util.func_name\nderiv/util func_name","url":"deriv/util.html#func_name"},{"doc":"deriv/util","title":"func_str","content":"pub fn func_str(func: Definition(Function)) -&gt; String\n\nSynonyms:\nderiv/util.func_str\nderiv/util func_str","url":"deriv/util.html#func_str"},{"doc":"deriv/util","title":"get_field_opts","content":"pub fn get_field_opts(\n  all_field_opts: Dict(DerivField, List(DerivFieldOpt)),\n  type_: CustomType,\n  variant: Variant,\n  field: String,\n) -&gt; List(DerivFieldOpt)\n\nSynonyms:\nderiv/util.get_field_opts\nderiv/util get_field_opts","url":"deriv/util.html#get_field_opts"},{"doc":"deriv/util","title":"gleam_format","content":"pub fn gleam_format(src: String) -&gt; String\n\nSynonyms:\nderiv/util.gleam_format\nderiv/util gleam_format","url":"deriv/util.html#gleam_format"},{"doc":"deriv/util","title":"indent","content":"pub fn indent(str: String, level level: Int) -&gt; String\n\nSynonyms:\nderiv/util.indent\nderiv/util indent","url":"deriv/util.html#indent"},{"doc":"deriv/util","title":"replace_function","content":"pub fn replace_function(\n  full_src: String,\n  func_name func_name: String,\n  func_src func_src: String,\n) -&gt; String\n\nSynonyms:\nderiv/util.replace_function\nderiv/util replace_function","url":"deriv/util.html#replace_function"},{"doc":"deriv/util","title":"snake_case","content":"pub fn snake_case(str: String) -&gt; String\n\nSynonyms:\nderiv/util.snake_case\nderiv/util snake_case","url":"deriv/util.html#snake_case"},{"doc":"deriv/util","title":"then","content":"pub fn then(\n  result: Result(a, b),\n  fun: fn(a) -&gt; Result(c, d),\n) -&gt; Result(c, Nil)\n\nSynonyms:\nderiv/util.then\nderiv/util then","url":"deriv/util.html#then"},{"doc":"deriv/util","title":"update_funcs","content":"pub fn update_funcs(\n  init_src: String,\n  funcs: List(#(String, String)),\n) -&gt; String\n\nSynonyms:\nderiv/util.update_funcs\nderiv/util update_funcs","url":"deriv/util.html#update_funcs"},{"doc":"deriv/util","title":"deriv/util","content":"","url":"deriv/util.html"},{"doc":"deriv/json","title":"gen","content":"pub fn gen(\n  type_: CustomType,\n  deriv: Derivation,\n  field_opts: Dict(DerivField, List(DerivFieldOpt)),\n  file: File,\n  module_reader: fn(String) -&gt; Result(Module, ModuleReaderErr),\n) -&gt; Gen\n\nSynonyms:\nderiv/json.gen\nderiv/json gen","url":"deriv/json.html#gen"},{"doc":"deriv/json","title":"suppress_option_warnings","content":"pub fn suppress_option_warnings() -&gt; List(Option(Nil))\n\nSynonyms:\nderiv/json.suppress_option_warnings\nderiv/json suppress_option_warnings","url":"deriv/json.html#suppress_option_warnings"},{"doc":"deriv/json","title":"deriv/json","content":"","url":"deriv/json.html"},{"doc":"deriv/unify","title":"GenFunc","content":"pub type GenFunc =\n  fn(CustomType, Derivation, DerivFieldOpts, File) -&gt; Gen\n\n\nSynonyms:\nderiv/unify.GenFunc\nderiv/unify GenFunc","url":"deriv/unify.html#GenFunc"},{"doc":"deriv/unify","title":"gen","content":"pub fn gen(\n  type_: CustomType,\n  deriv: Derivation,\n  field_opts: Dict(DerivField, List(DerivFieldOpt)),\n  file: File,\n  module_reader: fn(String) -&gt; Result(Module, ModuleReaderErr),\n) -&gt; Gen\n\nSynonyms:\nderiv/unify.gen\nderiv/unify gen","url":"deriv/unify.html#gen"},{"doc":"deriv/unify","title":"deriv/unify","content":"","url":"deriv/unify.html"},{"doc":"deriv","title":"build_different_file_writes","content":"pub fn build_different_file_writes(xs: List(Gen)) -&gt; List(Write)\n\nSynonyms:\nderiv.build_different_file_writes\nderiv build_different_file_writes","url":"deriv.html#build_different_file_writes"},{"doc":"deriv","title":"build_same_file_writes","content":"pub fn build_same_file_writes(xs: List(Gen)) -&gt; List(Write)\n\nSynonyms:\nderiv.build_same_file_writes\nderiv build_same_file_writes","url":"deriv.html#build_same_file_writes"},{"doc":"deriv","title":"build_writes","content":"pub fn build_writes(xs: List(Gen)) -&gt; List(Write)\n\nSynonyms:\nderiv.build_writes\nderiv build_writes","url":"deriv.html#build_writes"},{"doc":"deriv","title":"consolidate_imports","content":"pub fn consolidate_imports(\n  all_imports: List(Import),\n) -&gt; List(Import)\n\nSynonyms:\nderiv.consolidate_imports\nderiv consolidate_imports","url":"deriv.html#consolidate_imports"},{"doc":"deriv","title":"consolidate_imports_for","content":"pub fn consolidate_imports_for(\n  src: String,\n  add add_imports: List(Import),\n) -&gt; String\n\nSynonyms:\nderiv.consolidate_imports_for\nderiv consolidate_imports_for","url":"deriv.html#consolidate_imports_for"},{"doc":"deriv","title":"gen_derivs","content":"pub fn gen_derivs(\n  files: List(File),\n  module_reader: fn(String) -&gt; Result(Module, ModuleReaderErr),\n) -&gt; List(Gen)\n\nSynonyms:\nderiv.gen_derivs\nderiv gen_derivs","url":"deriv.html#gen_derivs"},{"doc":"deriv","title":"main","content":"pub fn main() -&gt; Nil\n\nSynonyms:\nderiv.main\nderiv main","url":"deriv.html#main"},{"doc":"deriv","title":"stop_warning","content":"pub fn stop_warning() -&gt; String\n\nSynonyms:\nderiv.stop_warning\nderiv stop_warning","url":"deriv.html#stop_warning"},{"doc":"deriv","title":"deriv","content":"/ ///// ///// ///// ///// /////","url":"deriv.html"},{"doc":"deriv/example/baz","title":"Baz","content":"pub type Baz {\n  Baz(baz: String)\n}\n\nBaz(baz: String)\n\n\nSynonyms:\nderiv/example/baz.Baz\nderiv/example/baz Baz","url":"deriv/example/baz.html#Baz"},{"doc":"deriv/example/baz","title":"Other","content":"pub type Other {\n  Other(other: Int)\n}\n\nOther(other: Int)\n\n\nSynonyms:\nderiv/example/baz.Other\nderiv/example/baz Other","url":"deriv/example/baz.html#Other"},{"doc":"deriv/example/baz","title":"deriv/example/baz","content":"","url":"deriv/example/baz.html"},{"doc":"deriv/deriv/example/baz/json","title":"decoder_baz","content":"pub fn decoder_baz() -&gt; Decoder(Baz)\n\nSynonyms:\nderiv/deriv/example/baz/json.decoder_baz\nderiv/deriv/example/baz/json decoder_baz","url":"deriv/deriv/example/baz/json.html#decoder_baz"},{"doc":"deriv/deriv/example/baz/json","title":"decoder_other","content":"pub fn decoder_other() -&gt; Decoder(Other)\n\nSynonyms:\nderiv/deriv/example/baz/json.decoder_other\nderiv/deriv/example/baz/json decoder_other","url":"deriv/deriv/example/baz/json.html#decoder_other"},{"doc":"deriv/deriv/example/baz/json","title":"encode_baz","content":"pub fn encode_baz(value: Baz) -&gt; Json\n\nSynonyms:\nderiv/deriv/example/baz/json.encode_baz\nderiv/deriv/example/baz/json encode_baz","url":"deriv/deriv/example/baz/json.html#encode_baz"},{"doc":"deriv/deriv/example/baz/json","title":"encode_other","content":"pub fn encode_other(value: Other) -&gt; Json\n\nSynonyms:\nderiv/deriv/example/baz/json.encode_other\nderiv/deriv/example/baz/json encode_other","url":"deriv/deriv/example/baz/json.html#encode_other"},{"doc":"deriv/deriv/example/baz/json","title":"deriv/deriv/example/baz/json","content":"","url":"deriv/deriv/example/baz/json.html"},{"doc":"deriv/derivs","title":"SuppressWarningsBaz","content":"pub type SuppressWarningsBaz =\n  Baz\n\n\nSynonyms:\nderiv/derivs.SuppressWarningsBaz\nderiv/derivs SuppressWarningsBaz","url":"deriv/derivs.html#SuppressWarningsBaz"},{"doc":"deriv/derivs","title":"SuppressWarningsOther","content":"pub type SuppressWarningsOther =\n  Other\n\n\nSynonyms:\nderiv/derivs.SuppressWarningsOther\nderiv/derivs SuppressWarningsOther","url":"deriv/derivs.html#SuppressWarningsOther"},{"doc":"deriv/derivs","title":"deriv/derivs","content":"","url":"deriv/derivs.html"},{"doc":"deriv/example/bar","title":"Baz","content":"pub type Baz {\n  Baz(id: Int, name: String, active: Bool)\n}\n\nBaz(id: Int, name: String, active: Bool)\n\n\nSynonyms:\nderiv/example/bar.Baz\nderiv/example/bar Baz","url":"deriv/example/bar.html#Baz"},{"doc":"deriv/example/bar","title":"decoder_baz","content":"pub fn decoder_baz() -&gt; Decoder(Baz)\n\nSynonyms:\nderiv/example/bar.decoder_baz\nderiv/example/bar decoder_baz","url":"deriv/example/bar.html#decoder_baz"},{"doc":"deriv/example/bar","title":"encode_baz","content":"pub fn encode_baz(value: Baz) -&gt; Json\n\nSynonyms:\nderiv/example/bar.encode_baz\nderiv/example/bar encode_baz","url":"deriv/example/bar.html#encode_baz"},{"doc":"deriv/example/bar","title":"deriv/example/bar","content":"","url":"deriv/example/bar.html"},{"doc":"deriv/example/birl","title":"DateTimeExamples","content":"pub type DateTimeExamples {\n  DateTimeExamples(\n    t0: Time,\n    t1: Time,\n    t2: Time,\n    t3: Time,\n    t4: Time,\n    t5: Time,\n    t6: Time,\n  )\n}\n\nDateTimeExamples(\n  t0: Time,\n  t1: Time,\n  t2: Time,\n  t3: Time,\n  t4: Time,\n  t5: Time,\n  t6: Time,\n)\n\n\nSynonyms:\nderiv/example/birl.DateTimeExamples\nderiv/example/birl DateTimeExamples","url":"deriv/example/birl.html#DateTimeExamples"},{"doc":"deriv/example/birl","title":"DictFieldType","content":"pub type DictFieldType {\n  DictFieldType(dict: Dict(String, Int))\n}\n\nDictFieldType(dict: Dict(String, Int))\n\n\nSynonyms:\nderiv/example/birl.DictFieldType\nderiv/example/birl DictFieldType","url":"deriv/example/birl.html#DictFieldType"},{"doc":"deriv/example/birl","title":"decoder_date_time_examples","content":"pub fn decoder_date_time_examples() -&gt; Decoder(DateTimeExamples)\n\nSynonyms:\nderiv/example/birl.decoder_date_time_examples\nderiv/example/birl decoder_date_time_examples","url":"deriv/example/birl.html#decoder_date_time_examples"},{"doc":"deriv/example/birl","title":"decoder_dict_field_type","content":"pub fn decoder_dict_field_type() -&gt; Decoder(DictFieldType)\n\nSynonyms:\nderiv/example/birl.decoder_dict_field_type\nderiv/example/birl decoder_dict_field_type","url":"deriv/example/birl.html#decoder_dict_field_type"},{"doc":"deriv/example/birl","title":"decoder_dict_field_type_dict_field_type","content":"pub fn decoder_dict_field_type_dict_field_type() -&gt; Decoder(\n  DictFieldType,\n)\n\nSynonyms:\nderiv/example/birl.decoder_dict_field_type_dict_field_type\nderiv/example/birl decoder_dict_field_type_dict_field_type","url":"deriv/example/birl.html#decoder_dict_field_type_dict_field_type"},{"doc":"deriv/example/birl","title":"encode_date_time_examples","content":"pub fn encode_date_time_examples(value: DateTimeExamples) -&gt; Json\n\nSynonyms:\nderiv/example/birl.encode_date_time_examples\nderiv/example/birl encode_date_time_examples","url":"deriv/example/birl.html#encode_date_time_examples"},{"doc":"deriv/example/birl","title":"encode_dict_field_type","content":"pub fn encode_dict_field_type(value: DictFieldType) -&gt; Json\n\nSynonyms:\nderiv/example/birl.encode_dict_field_type\nderiv/example/birl encode_dict_field_type","url":"deriv/example/birl.html#encode_dict_field_type"},{"doc":"deriv/example/birl","title":"deriv/example/birl","content":"","url":"deriv/example/birl.html"},{"doc":"deriv/example/foo","title":"Bar","content":"pub type Bar {\n  Bar(baz: Bool)\n}\n\nBar(baz: Bool)\n\n\nSynonyms:\nderiv/example/foo.Bar\nderiv/example/foo Bar","url":"deriv/example/foo.html#Bar"},{"doc":"deriv/example/foo","title":"Foo","content":"pub type Foo {\n  Foo(\n    uuid: Uuid,\n    id: Int,\n    name: String,\n    active: Bool,\n    ratio: Float,\n    maybe: Option(String),\n    words: List(String),\n  )\n}\n\nFoo(\n  uuid: Uuid,\n  id: Int,\n  name: String,\n  active: Bool,\n  ratio: Float,\n  maybe: Option(String),\n  words: List(String),\n)\n\n\nSynonyms:\nderiv/example/foo.Foo\nderiv/example/foo Foo","url":"deriv/example/foo.html#Foo"},{"doc":"deriv/example/foo","title":"decoder_bar","content":"pub fn decoder_bar() -&gt; Decoder(Bar)\n\nSynonyms:\nderiv/example/foo.decoder_bar\nderiv/example/foo decoder_bar","url":"deriv/example/foo.html#decoder_bar"},{"doc":"deriv/example/foo","title":"decoder_foo","content":"pub fn decoder_foo() -&gt; Decoder(Foo)\n\nSynonyms:\nderiv/example/foo.decoder_foo\nderiv/example/foo decoder_foo","url":"deriv/example/foo.html#decoder_foo"},{"doc":"deriv/example/foo","title":"encode_foo","content":"pub fn encode_foo(value: Foo) -&gt; Json\n\nSynonyms:\nderiv/example/foo.encode_foo\nderiv/example/foo encode_foo","url":"deriv/example/foo.html#encode_foo"},{"doc":"deriv/example/foo","title":"deriv/example/foo","content":"","url":"deriv/example/foo.html"},{"doc":"deriv/example/mvar","title":"T","content":"pub type T {\n  Var1(var1: String)\n  Var2(var2: Int)\n}\n\nVar1(var1: String)\n\n\nVar2(var2: Int)\n\n\nSynonyms:\nderiv/example/mvar.T\nderiv/example/mvar T","url":"deriv/example/mvar.html#T"},{"doc":"deriv/example/mvar","title":"decoder_t","content":"pub fn decoder_t() -&gt; Decoder(T)\n\nSynonyms:\nderiv/example/mvar.decoder_t\nderiv/example/mvar decoder_t","url":"deriv/example/mvar.html#decoder_t"},{"doc":"deriv/example/mvar","title":"deriv/example/mvar","content":"","url":"deriv/example/mvar.html"},{"doc":"deriv/example/unify","title":"AutheTokens","content":"pub type AutheTokens {\n  Authe(\n    id: Uuid,\n    encrypted_access_token: String,\n    encrypted_refresh_token: String,\n  )\n}\n\nAuthe(\n  id: Uuid,\n  encrypted_access_token: String,\n  encrypted_refresh_token: String,\n)\n\n\nSynonyms:\nderiv/example/unify.AutheTokens\nderiv/example/unify AutheTokens","url":"deriv/example/unify.html#AutheTokens"},{"doc":"deriv/example/unify","title":"AutheTypeA","content":"pub type AutheTypeA {\n  AutheTypeA(\n    user_id: Uuid,\n    name: String,\n    email: String,\n    org_id: Uuid,\n    authe_id: Uuid,\n    provider: String,\n    uid: Option(String),\n    aid: Option(String),\n    encrypted_access_token: String,\n    encrypted_refresh_token: String,\n  )\n}\n\nAutheTypeA(\n  user_id: Uuid,\n  name: String,\n  email: String,\n  org_id: Uuid,\n  authe_id: Uuid,\n  provider: String,\n  uid: Option(String),\n  aid: Option(String),\n  encrypted_access_token: String,\n  encrypted_refresh_token: String,\n)\n\n\nSynonyms:\nderiv/example/unify.AutheTypeA\nderiv/example/unify AutheTypeA","url":"deriv/example/unify.html#AutheTypeA"},{"doc":"deriv/example/unify","title":"AutheTypeB","content":"pub type AutheTypeB {\n  AutheTypeB(\n    user_id: Uuid,\n    name: String,\n    email: String,\n    org_id: Uuid,\n    authe_id: Uuid,\n    provider: String,\n    uid: Option(String),\n    aid: Option(String),\n    encrypted_access_token: String,\n    encrypted_refresh_token: String,\n  )\n}\n\nAutheTypeB(\n  user_id: Uuid,\n  name: String,\n  email: String,\n  org_id: Uuid,\n  authe_id: Uuid,\n  provider: String,\n  uid: Option(String),\n  aid: Option(String),\n  encrypted_access_token: String,\n  encrypted_refresh_token: String,\n)\n\n\nSynonyms:\nderiv/example/unify.AutheTypeB\nderiv/example/unify AutheTypeB","url":"deriv/example/unify.html#AutheTypeB"},{"doc":"deriv/example/unify","title":"authe_type_a","content":"pub fn authe_type_a(value: AutheTypeA) -&gt; AutheTokens\n\nSynonyms:\nderiv/example/unify.authe_type_a\nderiv/example/unify authe_type_a","url":"deriv/example/unify.html#authe_type_a"},{"doc":"deriv/example/unify","title":"authe_type_b","content":"pub fn authe_type_b(value: AutheTypeB) -&gt; AutheTokens\n\nSynonyms:\nderiv/example/unify.authe_type_b\nderiv/example/unify authe_type_b","url":"deriv/example/unify.html#authe_type_b"},{"doc":"deriv/example/unify","title":"suppress_option_warnings","content":"pub fn suppress_option_warnings() -&gt; List(Option(Nil))\n\nSynonyms:\nderiv/example/unify.suppress_option_warnings\nderiv/example/unify suppress_option_warnings","url":"deriv/example/unify.html#suppress_option_warnings"},{"doc":"deriv/example/unify","title":"deriv/example/unify","content":"","url":"deriv/example/unify.html"},{"doc":"deriv/example/unnested","title":"Unnested","content":"pub type Unnested {\n  Unnested(unnested: Int)\n}\n\nUnnested(unnested: Int)\n\n\nSynonyms:\nderiv/example/unnested.Unnested\nderiv/example/unnested Unnested","url":"deriv/example/unnested.html#Unnested"},{"doc":"deriv/example/unnested","title":"decoder_unnested","content":"pub fn decoder_unnested() -&gt; Decoder(Unnested)\n\nSynonyms:\nderiv/example/unnested.decoder_unnested\nderiv/example/unnested decoder_unnested","url":"deriv/example/unnested.html#decoder_unnested"},{"doc":"deriv/example/unnested","title":"decoder_unnested_unnested","content":"pub fn decoder_unnested_unnested() -&gt; Decoder(Unnested)\n\nSynonyms:\nderiv/example/unnested.decoder_unnested_unnested\nderiv/example/unnested decoder_unnested_unnested","url":"deriv/example/unnested.html#decoder_unnested_unnested"},{"doc":"deriv/example/unnested","title":"encode_unnested","content":"pub fn encode_unnested(value: Unnested) -&gt; Json\n\nSynonyms:\nderiv/example/unnested.encode_unnested\nderiv/example/unnested encode_unnested","url":"deriv/example/unnested.html#encode_unnested"},{"doc":"deriv/example/unnested","title":"deriv/example/unnested","content":"","url":"deriv/example/unnested.html"}]);